@@ -1,9 +1,7 @@
-import React from 'react';
 import { connect } from 'react-redux';
 import AutoSizer from 'react-virtualized-auto-sizer';
 
 import {
-  ArrayVector,
   FieldType,
   DataFrame,
   DateTime,
@@ -128,14 +126,14 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
   convertUserViewsToDataFrame(styles: InsightsStyles, theme: GrafanaTheme2): DataFrame | null {
     const { userViews } = this.props;
     if (userViews && userViews.length > 0) {
-      const time = new ArrayVector<string>([]);
-      const users = new ArrayVector<string>([]);
-      const avatars = new ArrayVector<JSX.Element>([]);
+      const time: string[] = [];
+      const users: string[] = [];
+      const avatars: JSX.Element[] = [];
 
       userViews.forEach((userView) => {
-        time.buffer.push(this.formatDate(dateTime(userView.lastActiveAt)));
-        users.buffer.push(userView.user.name);
-        avatars.buffer.push(<UserIcon className={styles.userIcon} userView={userView} showTooltip={false} />);
+        time.push(this.formatDate(dateTime(userView.lastActiveAt)));
+        users.push(userView.user.name);
+        avatars.push(<UserIcon className={styles.userIcon} userView={userView} showTooltip={false} />);
       });
 
       const avatarFieldConfig: FieldConfig<TableFieldOptions> = {
